#!/usr/bin/env python3

import sys
# import simulated python link library
import sply


def main ():
    model_id = "default-code"
    num_ctx = 1_000

    for argv in sys.argv[1:]:
        if argv.find("model_id=") == 0:
            model_id = argv[9:]

    # create a simulated python
    sp = sply.sp(
        show=True,
        model_id=model_id,
        num_ctx=num_ctx,
        )

    # set realish y's value to 1
    y = 1
    # print realish y's value
    print(f"y is {y}")

    # set y in simulated python to realish y + 1
    sp.runcode(f"y = {y} + 1")

    # set realish y's value to simulated y's value
    y = int(sp.runcode("y"))

    # print realish y's value
    print(f"y is {y}")

    #s.edit_prompt()
    return 0


if __name__ == "__main__":
    exit(main())




#!/usr/bin/env python3

import sply.overmind as overmind
n = overmind.node("n", "a primary node connected to the Overmind")
jane = n.node("jane", "a lady named Jane, age 25.")
print(jane["name"])

print(n("infer the meaning of a 'realism' property (i.e. jane[\"realism\"]) and briefly describe it to me"))

jane["realism"] = "90 percent human-like"
jane["IQ"] = "120.0"
user = n.node("user", "a reference to myself, a man named John")
jane["master"] = "user"
print(jane("how are you feeling today?"))

sue = n.node("sue", "Sue - a copy of Jane with various personal properties randomly changed by up to 20%")
sue["master"] = "user"
g = n.node("g", "an uninitialized node group")
g["members"] = ["jane", "sue"]
room = n.node("room", "a large and luxurious living room")
user["location"] = "room"
g["location"] = "room"
print(n("add some items to the living room that Jane and Sue would like"))

print(g("how do you like the room?"))




#!/usr/bin/env python3

import sys
import random
import sply

prompt = "; "\
         "You are a guile interpreter. "\
         "Assume the input code contains no mistakes or typos. "\
         "Your task is to evaulate the single current line of input,"\
         " then display the correct standard output. "\
         "Do not think out loud. "\
         "You will not generate markdown code blocks. "\
         "\n"\
         "scheme@(guile-user)> (+ 1 1)\n"\
         "$1 = 2\n"\
         "scheme@(guile-user)> (+ 2 1)\n"\
         "$1 = 3\n"


def main ():
    model_id = "default-code"
    num_ctx = 1_000

    for argv in sys.argv[1:]:
        if argv.find("model_id=") == 0:
            model_id = argv[9:]

    c = sply.chat(
        model_id=model_id,
        rev_prompt="\nscheme@(guile-user)> ",
        prompt=prompt,
        in_suffix_enabled=False,
        num_ctx=num_ctx,
        )

    print(c.prompt, end="", flush=True)
    c.read(show=True)

    c.write("(* 3 2)\n", show=True)
    c.read(show=True)

    print()
    return 0


if __name__ == "__main__":
    exit(main())





#!/usr/bin/env python3

import sys
import random
import sply


def main ():
    model_id = "default-code"
    seed = ""
    temp = 0.0
    num_ctx = 1_000

    for argv in sys.argv[1:]:
        if argv.find("model_id=") == 0:
            model_id = argv[9:]
        elif argv.find("seed=") == 0:
            seed = int(argv[5:])
        elif argv.find("temp=") == 0:
            temp = float(argv[5:])
        elif argv.find("num_ctx=") == 0:
            num_ctx = int(argv[8:])

    sp = sply.sp(
        show=True,
        model_id=model_id,
        seed=seed,
        temp=temp,
        num_ctx=num_ctx,
        )

    sp.runcode("i = 3 + 2")

    res = sp.runcode("print(i ** 3)")
    print(f"**{res}**")

    res = sp.runcode("print(pow (i, 3))")
    print(f"**{res}**")

    return 0


if __name__ == "__main__":
    exit(main())


